###################
Install from Source
###################

ADIOS2 uses `CMake <https://cmake.org/>`_ for building,
testing and installing the library and utilities.

.. include:: source/cmake.rst
.. include:: source/hpc_systems.rst
.. include:: source/cpp_c.rst
.. include:: source/python.rst
.. include:: source/fortran.rst
.. include:: source/ctest.rst
.. include:: source/examples.rst
